==> MetaModel-core-4.6.0-sources.jar: org/apache/metamodel/QueryPostprocessDelegate.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.metamodel;

import org.apache.metamodel.schema.Schema;

/**
 * A simple subclass of {@link QueryPostprocessDataContext} which provides less
 * implementation fuzz when custom querying features (like composite
 * datacontexts or type conversion) is needed.
 */
public abstract class QueryPostprocessDelegate extends
		QueryPostprocessDataContext {

	@Override
	protected String getMainSchemaName() throws MetaModelException {
		throw new UnsupportedOperationException(
				"QueryPostprocessDelegate cannot perform schema exploration");
	}

	@Override
	protected Schema getMainSchema() throws MetaModelException {
		throw new UnsupportedOperationException(
				"QueryPostprocessDelegate cannot perform schema exploration");
	}
}

==> MetaModel-core-5.3.2-sources.jar: org/apache/metamodel/QueryPostprocessDelegate.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.metamodel;

import org.apache.metamodel.schema.MutableSchema;

/**
 * A simple subclass of {@link QueryPostprocessDataContext} which provides less
 * implementation fuzz when custom querying features (like composite
 * datacontexts or type conversion) is needed.
 */
public abstract class QueryPostprocessDelegate extends
		QueryPostprocessDataContext {
    
    public QueryPostprocessDelegate() {
        super(false);
    }

	@Override
	protected String getMainSchemaName() throws MetaModelException {
		throw new UnsupportedOperationException(
				"QueryPostprocessDelegate cannot perform schema exploration");
	}

	@Override
	protected MutableSchema getMainSchema() throws MetaModelException {
		throw new UnsupportedOperationException(
				"QueryPostprocessDelegate cannot perform schema exploration");
	}
}
